symmetric_key_thumbprint

Function symmetric_key_thumbprint 

fn symmetric_key_thumbprint(key_bytes: &[u8]) -> CoseKeyThumbprint
Computes the RFC 9679 thumbprint of a COSE Symmetric key with the given k bytes. kty and k are the only required parameters for this key type, so they are the only ones hashed.